@@ -36,6 +36,9 @@ private slots:
     void declareVariadicFunction();
     void declareTypehintVariadicFunction();
     void declareTypehintObjectFunction();
+    void declareTypehintObjectFunctionWithNullDefault();
+    void declareTypehintObjectFunctionWithInvalidDefaultValue();
+    void declaredTypehintOverridesDetectedValue();
     void declareTypehintArrayFunction();
     void declareTypehintCallableFunction();
     void functionWithCallableAndFunctionReturn();
@@ -44,10 +47,12 @@ private slots:
     void declareTypehintFloatFunction();
     void declareTypehintIntFunction();
     void declareTypehintStringFunction();
+    void declareTypehintMixedFunction();
     void declareNullableTypehintArrayFunction();
     void declareNullableTypehintMixedFunction();
     void declareTypehintNullableIterableFunction();
     void declareTypehintWithPhpdocFunction();
+    void declareTypehintUnionFunction();
     void returnTypeGenerator_data();
     void returnTypeGenerator();
     void returnTypeGeneratorDelegation();
@@ -62,6 +67,7 @@ private slots:
     void declarationReturnTypeTypehint();
     void declarationReturnTypeTypehintVoid();
     void declarationReturnTypeTypehintObject();
+    void declarationReturnTypeTypehintUnion();
     void classImplementsInterface();
     void classExtends();
     void staticMethod();
@@ -195,6 +201,7 @@ private slots:
     void simpleExpression();
     void generatorAssignment();
     void generatorClosure();
+    void propertyUnionType();
 };
 
 }
